@@ -1,11 +1,12 @@
 package Perinci::Object::EnvResult;
 
+our $DATE = '2014-10-29'; # DATE
+our $VERSION = '0.17'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.16'; # VERSION
-
 sub new {
     my ($class, $res) = @_;
     $res //= [0, "", undef];
@@ -96,7 +97,7 @@ Perinci::Object::EnvResult - Represent enveloped result
 
 =head1 VERSION
 
-This document describes version 0.16 of Perinci::Object::EnvResult (from Perl distribution Perinci-Object), released on 2014-10-28.
+This document describes version 0.17 of Perinci::Object::EnvResult (from Perl distribution Perinci-Object), released on 2014-10-29.
 
 =head1 SYNOPSIS
 
@@ -171,7 +172,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ob
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Object>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Object>.
 
 =head1 BUGS
 
